@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -193,14 +193,14 @@ public class APNDriveEventPublisher implements DriveEventPublisher {
                 boolean production = access.isProduction();
                 String topic = access.getTopic();
                 if (store instanceof byte[]) {
-                    return new ApnsHttp2Options((byte[]) store, password, production, topic, null);
+                    return new ApnsHttp2Options((byte[]) store, password, production, topic);
                 }
                 if (!(store instanceof String)) {
                     break;
                 }
 
                 try (FileInputStream in = new FileInputStream((String) store)) {
-                    return new ApnsHttp2Options(IOUtils.toByteArray(in), password, production, topic, null);
+                    return new ApnsHttp2Options(IOUtils.toByteArray(in), password, production, topic);
                 } catch (Exception e) {
                     LOG.error("Error loading keystore", e);
                 }
@@ -213,14 +213,14 @@ public class APNDriveEventPublisher implements DriveEventPublisher {
                 String topic = access.getTopic();
                 boolean production = access.isProduction();
                 if (privateKey instanceof byte[]) {
-                    return new ApnsHttp2Options((byte[]) privateKey, keyId, teamId, production, topic, null);
+                    return new ApnsHttp2Options((byte[]) privateKey, keyId, teamId, production, topic);
                 }
                 if (!(privateKey instanceof String)) {
                     break;
                 }
 
                 try (FileInputStream in = new FileInputStream((String) privateKey)) {
-                    return new ApnsHttp2Options(IOUtils.toByteArray(in), keyId, teamId, production, topic, null);
+                    return new ApnsHttp2Options(IOUtils.toByteArray(in), keyId, teamId, production, topic);
                 } catch (Exception e) {
                     LOG.error("Error loading private key", e);
                 }
