@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -32,9 +32,9 @@ import com.openexchange.drive.events.apn2.util.SubscriptionDeliveryTask;
 import com.openexchange.drive.events.subscribe.Subscription;
 import com.openexchange.drive.events.subscribe.SubscriptionMode;
 import com.openexchange.server.ServiceLookup;
-import com.turo.pushy.apns.DeliveryPriority;
-import com.turo.pushy.apns.PushType;
-import com.turo.pushy.apns.util.SimpleApnsPushNotification;
+import com.eatthepath.pushy.apns.DeliveryPriority;
+import com.eatthepath.pushy.apns.PushType;
+import com.eatthepath.pushy.apns.util.SimpleApnsPushNotification;
 
 
 /**
