@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -22,15 +22,16 @@
 package com.openexchange.drive.events.apn2.util;
 
 import java.io.UnsupportedEncodingException;
+import java.time.Instant;
 import java.util.Date;
 import java.util.HashMap;
 import java.util.Map;
 import java.util.UUID;
 import com.fasterxml.jackson.core.JsonProcessingException;
 import com.fasterxml.jackson.databind.ObjectMapper;
-import com.turo.pushy.apns.DeliveryPriority;
-import com.turo.pushy.apns.PushType;
-import com.turo.pushy.apns.util.SimpleApnsPushNotification;
+import com.eatthepath.pushy.apns.DeliveryPriority;
+import com.eatthepath.pushy.apns.PushType;
+import com.eatthepath.pushy.apns.util.SimpleApnsPushNotification;
 
 
 /**
@@ -92,7 +93,7 @@ public class ApnsHttp2Notification extends SimpleApnsPushNotification {
             aps = new HashMap<>();
             alert = new HashMap<>();
             priority = null;
-            expiration = DEFAULT_EXPIRATION_PERIOD_MILLIS;
+            expiration = DEFAULT_EXPIRATION_PERIOD.toMillis();
         }
 
         public Builder withMutableContent(boolean mutable) {
@@ -237,7 +238,7 @@ public class ApnsHttp2Notification extends SimpleApnsPushNotification {
      * will assign a unique identifier automatically
      */
     public ApnsHttp2Notification(String token, String topic, Map<String, Object> payload, Date invalidationTime, DeliveryPriority priority, PushType pushType, String collapseId, UUID apnsId) {
-        super(token, topic, maptoString(payload), invalidationTime, priority, pushType, collapseId, apnsId);
+        super(token, topic, maptoString(payload), Instant.ofEpochMilli(invalidationTime.getTime()), priority, pushType, collapseId, apnsId);
     }
 
 }
