@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -23,7 +23,6 @@ package com.openexchange.drive.events.apn2.util;
 
 import java.io.File;
 import java.util.Arrays;
-import java.util.Optional;
 import com.openexchange.java.Strings;
 
 /**
@@ -95,8 +94,6 @@ public class ApnsHttp2Options {
 
     private final int hashCode;
 
-    private final Optional<String> domain;
-
     /**
      * Initializes a new immutable {@link ApnsHttp2Options} instance using a provider certificate.
      *
@@ -104,10 +101,9 @@ public class ApnsHttp2Options {
      * @param password The keystore's password.
      * @param production <code>true</code> to use Apple's production servers, <code>false</code> to use the sandbox servers
      * @param topic The app's topic, which is typically the bundle ID of the app
-     * @param domain The domain attribute or null
      */
-    public ApnsHttp2Options(File keystore, String password, boolean production, String topic, String domain) {
-        this(AuthType.CERTIFICATE, keystore, null, password, production, topic, null, null, null, domain);
+    public ApnsHttp2Options(File keystore, String password, boolean production, String topic) {
+        this(AuthType.CERTIFICATE, keystore, null, password, production, topic, null, null, null);
     }
 
     /**
@@ -117,10 +113,9 @@ public class ApnsHttp2Options {
      * @param password The keystore's password.
      * @param production <code>true</code> to use Apple's production servers, <code>false</code> to use the sandbox servers
      * @param topic The app's topic, which is typically the bundle ID of the app
-     * @param domain The domain attribute or null
      */
-    public ApnsHttp2Options(byte[] keystoreBytes, String password, boolean production, String topic, String domain) {
-        this(AuthType.CERTIFICATE, null, keystoreBytes, password, production, topic, null, null, null, domain);
+    public ApnsHttp2Options(byte[] keystoreBytes, String password, boolean production, String topic) {
+        this(AuthType.CERTIFICATE, null, keystoreBytes, password, production, topic, null, null, null);
     }
 
     /**
@@ -131,13 +126,12 @@ public class ApnsHttp2Options {
      * @param teamId The team identifier obtained from developer account
      * @param production <code>true</code> to use Apple's production servers, <code>false</code> to use the sandbox servers
      * @param topic The app's topic, which is typically the bundle ID of the app
-     * @param domain The domain attribute or null
      */
-    public ApnsHttp2Options(byte[] privateKey, String keyId, String teamId, boolean production, String topic, String domain) {
-        this(AuthType.JWT, null, null, null, production, topic, privateKey, keyId, teamId, domain);
+    public ApnsHttp2Options(byte[] privateKey, String keyId, String teamId, boolean production, String topic) {
+        this(AuthType.JWT, null, null, null, production, topic, privateKey, keyId, teamId);
     }
 
-    private ApnsHttp2Options(AuthType authType, File keystore, byte[] keystoreBytes, String password, boolean production, String topic, byte[] privateKey, String keyId, String teamId, String domain) {
+    private ApnsHttp2Options(AuthType authType, File keystore, byte[] keystoreBytes, String password, boolean production, String topic, byte[] privateKey, String keyId, String teamId) {
         super();
         this.authType = authType;
         this.keystore = keystore;
@@ -148,7 +142,6 @@ public class ApnsHttp2Options {
         this.privateKey = privateKey;
         this.keyId = keyId;
         this.teamId = teamId;
-        this.domain = Optional.ofNullable(domain);
 
         // hashcode
         final int prime = 31;
@@ -162,7 +155,6 @@ public class ApnsHttp2Options {
         result = prime * result + (production ? 1231 : 1237);
         result = prime * result + ((teamId == null) ? 0 : teamId.hashCode());
         result = prime * result + ((topic == null) ? 0 : topic.hashCode());
-        result = prime * result + ((domain == null) ? 0 : domain.hashCode());
         this.hashCode = result;
     }
 
@@ -233,15 +225,6 @@ public class ApnsHttp2Options {
         return privateKey;
     }
 
-    /**
-     * Gets the optional domain
-     *
-     * @return The optional domain
-     */
-    public Optional<String> optDomain() {
-        return domain;
-    }
-
     /**
      * Gets the apps's topic, which is typically the bundle ID of the app.
      *
@@ -315,10 +298,6 @@ public class ApnsHttp2Options {
         } else if (!topic.equals(other.topic)) {
             return false;
         }
-
-        if (domain.isPresent() != other.domain.isPresent() || (domain.isPresent() && false == domain.get().equals(other.domain.get()))) {
-            return false;
-        }
         return true;
     }
 
