@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -24,15 +24,9 @@ package com.openexchange.drive.events.apn2.util;
 import java.io.ByteArrayInputStream;
 import java.io.FileNotFoundException;
 import java.io.IOException;
-import java.net.InetSocketAddress;
-import java.net.Proxy;
-import java.net.ProxySelector;
-import java.net.SocketAddress;
-import java.net.URI;
 import java.net.URISyntaxException;
 import java.security.InvalidKeyException;
 import java.security.NoSuchAlgorithmException;
-import java.util.List;
 import java.util.Optional;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
@@ -40,11 +34,11 @@ import com.openexchange.drive.DriveExceptionCodes;
 import com.openexchange.drive.events.apn2.util.ApnsHttp2Options.AuthType;
 import com.openexchange.exception.OXException;
 import com.openexchange.java.Streams;
-import com.turo.pushy.apns.ApnsClient;
-import com.turo.pushy.apns.ApnsClientBuilder;
-import com.turo.pushy.apns.auth.ApnsSigningKey;
-import com.turo.pushy.apns.proxy.HttpProxyHandlerFactory;
-import com.turo.pushy.apns.proxy.ProxyHandlerFactory;
+import com.eatthepath.pushy.apns.ApnsClient;
+import com.eatthepath.pushy.apns.ApnsClientBuilder;
+import com.eatthepath.pushy.apns.auth.ApnsSigningKey;
+import com.eatthepath.pushy.apns.proxy.HttpProxyHandlerFactory;
+import com.eatthepath.pushy.apns.proxy.ProxyHandlerFactory;
 
 /**
  * {@link ApnsHttp2Utility} - APNS HTTP/2 utility class.
@@ -108,7 +102,7 @@ public class ApnsHttp2Utility {
                 clientBuilder.setSigningKey(ApnsSigningKey.loadFromInputStream(Streams.newByteArrayInputStream(options.getPrivateKey()), options.getTeamId(), options.getKeyId()));
             }
 
-            ProxyHandlerFactory proxyHandlerFactory = fromSystemProxies(apnsHost);
+            ProxyHandlerFactory proxyHandlerFactory = HttpProxyHandlerFactory.fromSystemProxies(apnsHost);
             if (proxyHandlerFactory != null) {
                 clientBuilder.setProxyHandlerFactory(proxyHandlerFactory);
             }
@@ -142,57 +136,4 @@ public class ApnsHttp2Utility {
         return Optional.empty();
     }
 
-    // -------------------------------------------------------------------------------------------------------------------------------------
-
-    private static final String PROXY_USERNAME_PROPERTY_KEY = "http.proxyUser";
-    private static final String PROXY_PASSWORD_PROPERTY_KEY = "http.proxyPassword";
-
-    /**
-     * Constructs an {@code HttpProxyHandlerFactory} that uses the HTTP proxy (if any) specified in Java's standard
-     * <a href="https://docs.oracle.com/javase/7/docs/api/java/net/doc-files/net-properties.html#Proxies">proxy system
-     * properties</a>.
-     *
-     * @param apnsHost the APNs host for which to find proxy settings
-     * @return an HTTP proxy factory if a proxy is configured for the given APNs host, or {@code null} if no proxy is
-     * configured for the given host
-     * @throws URISyntaxException if {@code apnsHost} is malformed in some way
-     *
-     * @see <a href="https://docs.oracle.com/javase/7/docs/api/java/net/doc-files/net-properties.html#Proxies">Java\u2122 Platform, Standard Edition 7 - Networking Properties - Proxies</a>
-     * @since 0.13.11
-     */
-    public static HttpProxyHandlerFactory fromSystemProxies(final String apnsHost) throws URISyntaxException {
-
-        final SocketAddress proxyAddress = getProxyAddressForUri(new URI("https", apnsHost, null, null));
-
-        return (proxyAddress != null)
-                ? new HttpProxyHandlerFactory(proxyAddress, System.getProperty(PROXY_USERNAME_PROPERTY_KEY), System.getProperty(PROXY_PASSWORD_PROPERTY_KEY))
-                : null;
-    }
-
-    /**
-     * Returns the {@link SocketAddress} for any system-wide HTTP {@link Proxy} for a given {@link URI}.
-     *
-     * @param uri the URI for which to find a system-wide proxy
-     * @return the {@link SocketAddress} of the first HTTP {@link Proxy} found, or {@code null} if there were none
-     * @since 0.13.11
-     */
-    private static SocketAddress getProxyAddressForUri(final URI uri) {
-        final ProxySelector defaultProxySelector = ProxySelector.getDefault();
-        final List<Proxy> proxiesForUri = defaultProxySelector.select(uri);
-
-        for (final java.net.Proxy proxy : proxiesForUri) {
-            if (proxy.type() == Proxy.Type.HTTP) {
-                InetSocketAddress proxyAddress = (InetSocketAddress) proxy.address();
-
-                if (proxyAddress.isUnresolved()) {
-                    proxyAddress = new InetSocketAddress(proxyAddress.getHostString(), proxyAddress.getPort());
-                }
-
-                return proxyAddress;
-            }
-        }
-
-        return null;
-    }
-
 }
