@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -30,10 +30,10 @@ import com.openexchange.exception.OXException;
 import com.openexchange.java.Strings;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.threadpool.AbstractTask;
-import com.turo.pushy.apns.ApnsClient;
-import com.turo.pushy.apns.PushNotificationResponse;
-import com.turo.pushy.apns.util.SimpleApnsPushNotification;
-import com.turo.pushy.apns.util.concurrent.PushNotificationFuture;
+import com.eatthepath.pushy.apns.ApnsClient;
+import com.eatthepath.pushy.apns.PushNotificationResponse;
+import com.eatthepath.pushy.apns.util.SimpleApnsPushNotification;
+import com.eatthepath.pushy.apns.util.concurrent.PushNotificationFuture;
 
 /**
  * {@link SubscriptionDeliveryTask}
@@ -67,7 +67,7 @@ public abstract class SubscriptionDeliveryTask extends AbstractTask<Void> {
     }
 
     /**
-     * Constructs a {@link SimpleApnsPushNotification} based on given {@link DriveEvent}, {@link Subscription} and {@link ApnsHttp2Options} 
+     * Constructs a {@link SimpleApnsPushNotification} based on given {@link DriveEvent}, {@link Subscription} and {@link ApnsHttp2Options}
      *
      * @param event The drive event
      * @param subscription The subscription
@@ -117,10 +117,16 @@ public abstract class SubscriptionDeliveryTask extends AbstractTask<Void> {
 
     // Checks if rejectionReason is because of invalid token
     // see section 'Understand Error Codes' https://developer.apple.com/documentation/usernotifications/setting_up_a_remote_notification_server/handling_notification_responses_from_apns
-    private boolean isInvalidToken(String rejectionReason) {
+    private boolean isInvalidToken(Optional<String> optionalRejectionReason) {
+        if (optionalRejectionReason.isPresent() == false) {
+            return false;
+        }
+
+        String rejectionReason = optionalRejectionReason.get();
         if (Strings.isEmpty(rejectionReason)) {
             return false;
         }
+
         return "BadDeviceToken".equals(rejectionReason) || "Unregistered".equals(rejectionReason);
     }
 
