@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -101,11 +101,6 @@ public enum DriveEventsAPN2IOSProperty implements Property {
      * Default: no default
      */
     teamid(null),
-
-    /**
-     * The domain field sent with every push message. If set it is also used as the collapse id.
-     */
-    domain("myFiles")
     ;
 
     public static final String FRAGMENT_FILE_NAME = "drive.properties";
