@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -148,9 +148,8 @@ public class ApnsHttp2DriveEventsActivator extends HousekeepingActivator {
                     String keyId = getProperty(properties, DriveEventsAPN2IOSProperty.keyid);
                     String teamId = getProperty(properties, DriveEventsAPN2IOSProperty.teamid);
                     String topic = getProperty(properties, DriveEventsAPN2IOSProperty.topic);
-                    String domain = getProperty(properties, DriveEventsAPN2IOSProperty.domain);
                     boolean production = Boolean.parseBoolean(getProperty(properties, DriveEventsAPN2IOSProperty.production));
-                    return new ApnsHttp2Options(privateKey, keyId, teamId, production, topic, domain);
+                    return new ApnsHttp2Options(privateKey, keyId, teamId, production, topic);
                 } catch (IOException e) {
                     LOG.error("Error instantiating APNS HTTP/2 options from {}", privateKeyFileName, e);
                     return null;
@@ -175,9 +174,8 @@ public class ApnsHttp2DriveEventsActivator extends HousekeepingActivator {
 
                     String password = getProperty(properties, DriveEventsAPN2IOSProperty.password);
                     String topic = getProperty(properties, DriveEventsAPN2IOSProperty.topic);
-                    String domain = getProperty(properties, DriveEventsAPN2IOSProperty.domain);
                     boolean production = Boolean.parseBoolean(getProperty(properties, DriveEventsAPN2IOSProperty.production));
-                    return new ApnsHttp2Options(keystore, password, production, topic, domain);
+                    return new ApnsHttp2Options(keystore, password, production, topic);
                 } catch (IOException e) {
                     LOG.error("Error instantiating APNS HTTP/2 options from {}", keystoreFileName, e);
                     return null;
