@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -35,6 +35,21 @@ import com.openexchange.java.Strings;
  */
 public class Subscription {
 
+    /** The push domain name representing the <i>My files</i> subtree */
+    public static final String DOMAIN_MY_FILES = "myFiles";
+
+    /** The push domain name representing the <i>Shared files</i> subtree */
+    public static final String DOMAIN_SHARED_FILES = "sharedFiles";
+
+    /** The push domain name representing the <i>Public files</i> subtree */
+    public static final String DOMAIN_PUBLIC_FILES = "publicFiles";
+
+    /** The static root folder identifier of the <i>Shared files</i> subtree */
+    private static final String SHARED_FILES_FOLDER_ID = "10"; // com.openexchange.groupware.container.FolderObject.SYSTEM_USER_INFOSTORE_FOLDER_ID
+
+    /** The static root folder identifier of the <i>Public files</i> subtree */
+    private static final String PUBLIC_FILES_FOLDER_ID = "15"; // com.openexchange.groupware.container.FolderObject.SYSTEM_PUBLIC_INFOSTORE_FOLDER_ID
+
     private String uuid;
     private String serviceID;
     private String token;
@@ -204,6 +219,21 @@ public class Subscription {
         this.mode = mode;
     }
 
+    /**
+     * Gets the push domain, as derived from the root folder id.
+     * 
+     * @return The domain
+     */
+    public String getDomain() {
+        if (SHARED_FILES_FOLDER_ID.equals(rootFolderID)) {
+            return DOMAIN_SHARED_FILES;
+        }
+        if (PUBLIC_FILES_FOLDER_ID.equals(rootFolderID)) {
+            return DOMAIN_PUBLIC_FILES;
+        }
+        return DOMAIN_MY_FILES;
+    }
+
     /**
      * Gets a value indicating whether this subscription's push registration token matches the supplied token value, trying to match
      * either the token itself or the md5 checksum of the token.
