@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -36,6 +36,7 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.UUID;
+import java.util.stream.Collectors;
 import com.openexchange.database.DatabaseService;
 import com.openexchange.database.Databases;
 import com.openexchange.drive.DriveExceptionCodes;
@@ -134,18 +135,18 @@ public class RdbChecksumStore implements ChecksumStore {
 
     @Override
     public List<FileChecksum> updateFileChecksums(List<FileChecksum> fileChecksums) throws OXException {
-        Connection connection = databaseService.getWritable(contextID);
-        try {
-            for (FileChecksum fileChecksum : fileChecksums) {
-                if (null == fileChecksum.getUuid()) {
-                    throw new IllegalArgumentException("Updating file checksums requires an existing UUID");
+        List<FileChecksum> storedChecksums = fileChecksums.stream().filter(f -> null != f.getUuid()).collect(Collectors.toList());
+        if (false == storedChecksums.isEmpty()) {
+            Connection connection = databaseService.getWritable(contextID);
+            try {
+                for (FileChecksum fileChecksum : storedChecksums) {
+                    updateFileChecksum(connection, contextID, fileChecksum);
                 }
-                updateFileChecksum(connection, contextID, fileChecksum);
+            } catch (SQLException e) {
+                throw SQL.wrap(e);
+            } finally {
+                databaseService.backWritable(contextID, connection);
             }
-        } catch (SQLException e) {
-            throw SQL.wrap(e);
-        } finally {
-            databaseService.backWritable(contextID, connection);
         }
         return fileChecksums;
     }
@@ -169,21 +170,21 @@ public class RdbChecksumStore implements ChecksumStore {
 
     @Override
     public int removeFileChecksums(List<FileChecksum> fileChecksums) throws OXException {
+        List<FileChecksum> storedChecksums = fileChecksums.stream().filter(f -> null != f.getUuid()).collect(Collectors.toList());
+        if (storedChecksums.isEmpty()) {
+            return 0;
+        }
         Connection connection = databaseService.getWritable(contextID);
         try {
             int deleted = 0;
-            for (int i = 0; i < fileChecksums.size(); i += DELETE_CHUNK_SIZE) {
+            for (int i = 0; i < storedChecksums.size(); i += DELETE_CHUNK_SIZE) {
                 /*
                  * prepare chunk
                  */
-                int length = Math.min(fileChecksums.size(), i + DELETE_CHUNK_SIZE) - i;
+                int length = Math.min(storedChecksums.size(), i + DELETE_CHUNK_SIZE) - i;
                 String[] uuids = new String[length];
                 for (int j = 0; j < length; j++) {
-                    String uuid = fileChecksums.get(i + j).getUuid();
-                    if (null == uuid) {
-                        throw new IllegalArgumentException("Removing file checksums requires an existing UUID");
-                    }
-                    uuids[j] = uuid;
+                    uuids[j] = storedChecksums.get(i + j).getUuid();
                 }
                 /*
                  * delete chunk
@@ -207,6 +208,30 @@ public class RdbChecksumStore implements ChecksumStore {
     public int removeFileChecksumsInFolders(List<FolderID> folderIDs) throws OXException {
         int deleted = 0;
         Connection connection = databaseService.getWritable(contextID);
+        try {
+            deleted = removeFileChecksumsInFolders(connection, contextID, folderIDs);
+            return deleted;
+        } finally {
+            if (0 < deleted) {
+                databaseService.backWritable(contextID, connection);
+            } else {
+                databaseService.backWritableAfterReading(contextID, connection);
+            }
+        }
+    }
+
+    /**
+     *
+     * Removes all file checksums matching one of the supplied folder IDs.
+     *
+     * @param connection The database connection
+     * @param contextID The context id
+     * @param folderIDs The folder IDs of the checksums to remove
+     * @return The number of removed checksums
+     * @throws OXException
+     */
+    public static int removeFileChecksumsInFolders(Connection connection, int contextID, List<FolderID> folderIDs) throws OXException {
+        int deleted = 0;
         try {
             for (int i = 0; i < folderIDs.size(); i += DELETE_CHUNK_SIZE) {
                 /*
@@ -222,12 +247,6 @@ public class RdbChecksumStore implements ChecksumStore {
             return deleted;
         } catch (SQLException e) {
             throw SQL.wrap(e);
-        } finally {
-            if (0 < deleted) {
-                databaseService.backWritable(contextID, connection);
-            } else {
-                databaseService.backWritableAfterReading(contextID, connection);
-            }
         }
     }
 
@@ -470,21 +489,54 @@ public class RdbChecksumStore implements ChecksumStore {
     public List<DirectoryChecksum> getUnusedDirectoryChecksums(long unusedSince) throws OXException {
         Connection connection = databaseService.getReadOnly(contextID);
         try {
-            return selectUnusedDirectoryChecksums(connection, contextID, unusedSince);
-        } catch (SQLException e) {
-            throw SQL.wrap(e);
+            return getUnusedDirectoryChecksums(connection, contextID, unusedSince);
         } finally {
             databaseService.backReadOnly(contextID, connection);
         }
     }
 
+    /**
+     * Gets a list of directory checksums that were not "used", i.e. not have been inserted/updated or touched since the supplied
+     * timestamp.
+     *
+     * @param connection The database connection
+     * @param contextID The context id
+     * @param unusedSince The maximum "used" timestamp of a checksum to be considered as "unused"
+     * @return The unused checksums, or <code>null</code> if there are none
+     */
+    public static List<DirectoryChecksum> getUnusedDirectoryChecksums(Connection connection, int contextID, long unusedSince) throws OXException {
+        try {
+            return selectUnusedDirectoryChecksums(connection, contextID, unusedSince);
+        } catch (SQLException e) {
+            throw SQL.wrap(e);
+        }
+    }
+
     @Override
     public List<DirectoryChecksum> getDirectoryChecksums(List<FolderID> folderIDs) throws OXException {
+        Connection connection = databaseService.getReadOnly(contextID);
+        try {
+            return getDirectoryChecksums(connection, contextID, folderIDs);
+        } finally {
+            databaseService.backReadOnly(contextID, connection);
+        }
+    }
+
+    /**
+     *
+     * Gets the directory checksums.
+     *
+     * @param connection The database connection
+     * @param contextID The context id
+     * @param folderIDs The folder ids
+     * @return A list with directory checksums.
+     * @throws OXException
+     */
+    public static List<DirectoryChecksum> getDirectoryChecksums(Connection connection, int contextID, List<FolderID> folderIDs) throws OXException {
         if (null == folderIDs) {
             return Collections.emptyList();
         }
         List<DirectoryChecksum> checksums = new ArrayList<DirectoryChecksum>();
-        Connection connection = databaseService.getReadOnly(contextID);
         try {
             /*
              * select chunk-wise
@@ -496,14 +548,30 @@ public class RdbChecksumStore implements ChecksumStore {
             return checksums;
         } catch (SQLException e) {
             throw SQL.wrap(e);
-        } finally {
-            databaseService.backReadOnly(contextID, connection);
         }
     }
 
     @Override
     public int removeDirectoryChecksums(List<DirectoryChecksum> directoryChecksums) throws OXException {
         Connection connection = databaseService.getWritable(contextID);
+        try {
+            return removeDirectoryChecksums(connection, contextID, directoryChecksums);
+        } finally {
+            databaseService.backWritable(contextID, connection);
+        }
+    }
+
+    /**
+     *
+     * Removes the directory checksums.
+     *
+     * @param connection The database connection
+     * @param contextID The context id
+     * @param directoryChecksums The directory checksums to remove
+     * @return The number of deleted checksums.
+     * @throws OXException
+     */
+    public static int removeDirectoryChecksums(Connection connection, int contextID, List<DirectoryChecksum> directoryChecksums) throws OXException {
         try {
             int deleted = 0;
             for (int i = 0; i < directoryChecksums.size(); i += DELETE_CHUNK_SIZE) {
@@ -527,8 +595,6 @@ public class RdbChecksumStore implements ChecksumStore {
             return deleted;
         } catch (SQLException e) {
             throw SQL.wrap(e);
-        } finally {
-            databaseService.backWritable(contextID, connection);
         }
     }
 
