@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -171,9 +171,8 @@ public class DriveUtils {
      * @param path The directory path, relative to the root directory
      * @param fileName The filename to check
      * @return <code>true</code> if the filename is considered to be ignored, <code>false</code>, otherwise
-     * @throws OXException
      */
-    public static boolean isIgnoredFileName(DriveSession session, String path, String fileName) {
+    public static boolean isIgnoredFileName(DriveSession session, String path, String fileName) throws OXException {
         if (isIgnoredFileName(fileName, new DriveConfig(session.getServerSession().getContextId(), session.getServerSession().getUserId()))) {
             return true;
         }
@@ -197,7 +196,7 @@ public class DriveUtils {
      * @param fileName The filename to check
      * @return <code>true</code> if the filename is considered to be ignored, <code>false</code>, otherwise
      */
-    public static boolean isIgnoredFileName(SyncSession session, String path, String fileName) {
+    public static boolean isIgnoredFileName(SyncSession session, String path, String fileName) throws OXException {
         if (isIgnoredFileName(fileName, session.getConfig())) {
             return true;
         }
@@ -430,7 +429,7 @@ public class DriveUtils {
             throw DriveExceptionCodes.INVALID_PATH.create(path);
         }
         LinkedList<String> names = new LinkedList<String>();
-        for (String name : path.split(String.valueOf(PATH_SEPARATOR))) {
+        for (String name : Strings.splitBy(path, PATH_SEPARATOR, true)) {
             if (Strings.isEmpty(name)) {
                 continue;
             }
