@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -26,6 +26,7 @@ import java.util.Collection;
 import java.util.List;
 import com.openexchange.drive.DirectoryPattern;
 import com.openexchange.drive.DirectoryVersion;
+import com.openexchange.exception.OXException;
 
 
 /**
@@ -44,7 +45,7 @@ public class FilteringDirectoryVersionMapper extends DirectoryVersionMapper {
      * @param serverVersions The current server versions
      */
     public FilteringDirectoryVersionMapper(List<DirectoryPattern> directoryExclusions, Collection<? extends DirectoryVersion> originalVersions,
-        Collection<? extends DirectoryVersion> clientVersions, Collection<? extends DirectoryVersion> serverVersions) {
+        Collection<? extends DirectoryVersion> clientVersions, Collection<? extends DirectoryVersion> serverVersions) throws OXException {
         super(filterExclusions(originalVersions, directoryExclusions), clientVersions,
             filterExclusions(serverVersions, directoryExclusions));
     }
@@ -61,7 +62,7 @@ public class FilteringDirectoryVersionMapper extends DirectoryVersionMapper {
      * @param directoryExclusions The directory exclusions, or <code>null</code> if there are none
      * @return A filtered collection
      */
-    private static Collection<? extends DirectoryVersion> filterExclusions(Collection<? extends DirectoryVersion> directoryVersions, List<DirectoryPattern> directoryExclusions) {
+    private static Collection<? extends DirectoryVersion> filterExclusions(Collection<? extends DirectoryVersion> directoryVersions, List<DirectoryPattern> directoryExclusions) throws OXException {
         if (null == directoryExclusions || 0 == directoryExclusions.size()) {
             return directoryVersions;
         }
@@ -81,7 +82,7 @@ public class FilteringDirectoryVersionMapper extends DirectoryVersionMapper {
      * @param patterns The patterns
      * @return <code>true</code> if any of the patterns matches the directory version, <code>false</code>, otherwise
      */
-    private static boolean matchesAny(DirectoryVersion directoryVersion, List<DirectoryPattern> patterns) {
+    private static boolean matchesAny(DirectoryVersion directoryVersion, List<DirectoryPattern> patterns) throws OXException {
         String path = directoryVersion.getPath();
         for (DirectoryPattern directoryExclusion : patterns) {
             if (directoryExclusion.matches(path)) {
