@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -26,6 +26,7 @@ import java.util.Collection;
 import java.util.List;
 import com.openexchange.drive.FilePattern;
 import com.openexchange.drive.FileVersion;
+import com.openexchange.exception.OXException;
 
 
 /**
@@ -45,7 +46,7 @@ public class FilteringFileVersionMapper extends FileVersionMapper {
      * @param serverVersions The current server versions
      */
     public FilteringFileVersionMapper(String path, List<FilePattern> fileExclusions, Collection<? extends FileVersion> originalVersions,
-        Collection<? extends FileVersion> clientVersions, Collection<? extends FileVersion> serverVersions) {
+        Collection<? extends FileVersion> clientVersions, Collection<? extends FileVersion> serverVersions) throws OXException {
         super(filterExclusions(path, originalVersions, fileExclusions), clientVersions,
             filterExclusions(path, serverVersions, fileExclusions));
     }
@@ -63,7 +64,7 @@ public class FilteringFileVersionMapper extends FileVersionMapper {
      * @param fileExclusions The file exclusions, or <code>null</code> if there are none
      * @return A filtered collection
      */
-    private static Collection<? extends FileVersion> filterExclusions(String path, Collection<? extends FileVersion> fileVersions, List<FilePattern> fileExclusions) {
+    private static Collection<? extends FileVersion> filterExclusions(String path, Collection<? extends FileVersion> fileVersions, List<FilePattern> fileExclusions) throws OXException {
         if (null == fileExclusions || 0 == fileExclusions.size()) {
             return fileVersions;
         }
@@ -84,7 +85,7 @@ public class FilteringFileVersionMapper extends FileVersionMapper {
      * @param patterns The patterns
      * @return <code>true</code> if any of the patterns matches the file version, <code>false</code>, otherwise
      */
-    private static boolean matchesAny(String path, FileVersion fileVersion, List<FilePattern> patterns) {
+    private static boolean matchesAny(String path, FileVersion fileVersion, List<FilePattern> patterns) throws OXException {
         String name = fileVersion.getName();
         for (FilePattern fileExclusion : patterns) {
             if (fileExclusion.matches(path, name)) {
