@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -177,12 +177,14 @@ public class DriveServiceImpl implements DriveService {
         DriveVersionValidator.validateDirectoryVersions(originalVersions);
         DriveVersionValidator.validateDirectoryVersions(clientVersions);
         List<ServerDirectoryVersion> serverVersions;
+        long maxProcessingTime = driveConfig.getMaxSyncProcessingTime();
         int retryCount = 0;
         while (true) {
             /*
              * init sync session & check root folder validity
              */
-            final SyncSession driveSession = new SyncSession(session);
+            long remainingProcessingTime = 0 < maxProcessingTime ? Math.max(1L, start + maxProcessingTime - System.currentTimeMillis()) : -1L;
+            final SyncSession driveSession = new SyncSession(session, remainingProcessingTime);
             FileStorageFolder rootFolder;
             try {
                 rootFolder = driveSession.getStorage().getFolder(DriveConstants.ROOT_PATH);
@@ -271,8 +273,9 @@ public class DriveServiceImpl implements DriveService {
                 driveSession.trace("syncFolders with " + syncResult.length() + " resulting action(s) completed after "
                     + (System.currentTimeMillis() - start) + "ms.");
             }
-            String pathToRoot = driveSession.getStorage().getInternalPath(session.getRootFolderID());
-            return new DefaultSyncResult<DirectoryVersion>(actionsForClient, driveSession.getDiagnosticsLog(), quota, pathToRoot);
+            String pathToRoot = driveSession.getStorage().getInternalPath(session.getRootFolderID(), null);
+            String localizedPathToRoot = driveSession.getStorage().getInternalPath(session.getRootFolderID(), session.getLocale());
+            return new DefaultSyncResult<DirectoryVersion>(actionsForClient, driveSession.getDiagnosticsLog(), quota, pathToRoot, localizedPathToRoot);
         }
     }
 
@@ -289,12 +292,14 @@ public class DriveServiceImpl implements DriveService {
         if (false == DriveUtils.isSynchronizable(session.getRootFolderID(), driveConfig)) {
             return getErrorResult(session, path, DriveExceptionCodes.NOT_SYNCHRONIZABLE_DIRECTORY.create(session.getRootFolderID()), true);
         }
+        long maxProcessingTime = driveConfig.getMaxSyncProcessingTime();
         int retryCount = 0;
         while (true) {
             /*
              * init sync session & check root folder validity
              */
-            final SyncSession driveSession = new SyncSession(session);
+            long remainingProcessingTime = 0 < maxProcessingTime ? Math.max(1L, start + maxProcessingTime - System.currentTimeMillis()) : -1L;
+            final SyncSession driveSession = new SyncSession(session, remainingProcessingTime);
             FileStorageFolder rootFolder;
             try {
                 rootFolder = driveSession.getStorage().getFolder(DriveConstants.ROOT_PATH);
@@ -359,8 +364,9 @@ public class DriveServiceImpl implements DriveService {
                 driveSession.trace("syncFiles with " + syncResult.length() + " resulting action(s) completed after "
                     + (System.currentTimeMillis() - start) + "ms.");
             }
-            String pathToRoot = driveSession.getStorage().getInternalPath(session.getRootFolderID());
-            return new DefaultSyncResult<FileVersion>(actionsForClient, driveSession.getDiagnosticsLog(), quota, pathToRoot);
+            String pathToRoot = driveSession.getStorage().getInternalPath(session.getRootFolderID(), null);
+            String localizedPathToRoot = driveSession.getStorage().getInternalPath(session.getRootFolderID(), session.getLocale());
+            return new DefaultSyncResult<FileVersion>(actionsForClient, driveSession.getDiagnosticsLog(), quota, pathToRoot, localizedPathToRoot);
         }
     }
 
@@ -432,8 +438,11 @@ public class DriveServiceImpl implements DriveService {
             /*
              * store checksum, invalidate parent directory checksum
              */
-            FileChecksum fileChecksum = syncSession.getChecksumStore().insertFileChecksum(new FileChecksum(
-                DriveUtils.getFileID(createdFile), createdFile.getVersion(), createdFile.getSequenceNumber(), newVersion.getChecksum()));
+            FileChecksum fileChecksum = new FileChecksum(
+                DriveUtils.getFileID(createdFile), createdFile.getVersion(), createdFile.getSequenceNumber(), newVersion.getChecksum());
+            if (Strings.isEmpty(createdFile.getFileMD5Sum())) {
+                fileChecksum = syncSession.getChecksumStore().insertFileChecksum(fileChecksum);
+            }
             syncSession.getChecksumStore().removeDirectoryChecksum(new FolderID(createdFile.getFolderId()));
             /*
              * check if created file still equals uploaded one
@@ -480,7 +489,8 @@ public class DriveServiceImpl implements DriveService {
         settings.setSupportedApiVersion(String.valueOf(DriveConstants.SUPPORTED_API_VERSION));
         settings.setMinUploadChunk(Long.valueOf(syncSession.getOptimisticSaveThreshold()));
         settings.setHasTrashFolder(storage.hasTrashFolder());
-        settings.setPathToRoot(storage.getInternalPath(session.getRootFolderID()));
+        settings.setPathToRoot(storage.getInternalPath(session.getRootFolderID(), null));
+        settings.setLocalizedPathToRoot(storage.getInternalPath(session.getRootFolderID(), session.getLocale()));
         settings.setMaxConcurrentSyncFiles(driveConfig.getMaxConcurrentSyncFiles());
         /*
          * add any localized folder names (up to a certain depth after which no localized names are expected anymore)
@@ -490,7 +500,7 @@ public class DriveServiceImpl implements DriveService {
         Map<String, FileStorageFolder> folders = storage.getFolders(maxDirectories, 2);
         for (Map.Entry<String, FileStorageFolder> entry : folders.entrySet()) {
             String localizedName = entry.getValue().getLocalizedName(session.getLocale());
-            if (Strings.isNotEmpty(localizedName) && false == localizedName.equals(entry.getValue().getName())) {
+            if (Strings.isNotEmpty(localizedName)) {
                 localizedFolders.put(entry.getKey(), localizedName);
             }
         }
@@ -649,6 +659,9 @@ public class DriveServiceImpl implements DriveService {
      * @return <code>true</code> if the operation may be tried again, <code>false</code>, otherwise
      */
     private static boolean tryAgain(SyncSession session, OXException e, int retryCount, String message) {
+        if (DriveExceptionCodes.SERVER_BUSY.equals(e)) {
+            return false;
+        }
         if (0 == retryCount || (mayTryAgain(e) && retryCount <= DriveConstants.MAX_RETRIES)) {
             int delay = DriveConstants.RETRY_BASEDELAY * retryCount + DriveConstants.RANDOM.nextInt(1000);
             session.trace(message + " (" + e.getMessage() + "), trying again in " + delay + "ms" +
