@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -723,7 +723,7 @@ public class DriveUtilityImpl implements DriveUtility {
                 UserizedFolder folder = getFolderFor(folderId, session);
                 Locale locale = session.getDriveSession().getLocale();
                 StringBuilder sb = new StringBuilder();
-                sb.append(folder.getLocalizedName(locale));
+                sb.append(folder.getName(locale));
 
                 if (!originPath.isEmpty()) {
                     boolean searchInSubfolders = true;
@@ -735,7 +735,7 @@ public class DriveUtilityImpl implements DriveUtility {
                                 UserizedFolder subfolder = subfolders[i];
                                 if (folderName.equals(subfolder.getName())) {
                                     found = true;
-                                    sb.append("/").append(subfolder.getLocalizedName(locale));
+                                    sb.append("/").append(subfolder.getName(locale));
                                 }
                             }
                         }
@@ -798,8 +798,8 @@ public class DriveUtilityImpl implements DriveUtility {
         try {
             Entities filteredEntities = new Entities();
             for (Integer id : entities.getGroups()) {
-                Permission permission = filteredEntities.getGroupPermissionBits(id.intValue());
-                filteredEntities.addUser(id.intValue(), permission.getType(), permission.getPermissions());
+                Permission permission = entities.getGroupPermissionBits(id.intValue());
+                filteredEntities.addGroup(id.intValue(), permission.getType(), permission.getPermissions());
             }
             UserService userService = DriveServiceLookup.getService(UserService.class, true);
             for (Integer id : entities.getUsers()) {
