@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -27,6 +27,7 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
 import java.util.Map;
+import java.util.concurrent.TimeUnit;
 import com.openexchange.capabilities.CapabilityService;
 import com.openexchange.capabilities.CapabilitySet;
 import com.openexchange.drive.DriveExceptionCodes;
@@ -36,8 +37,10 @@ import com.openexchange.drive.checksum.rdb.RdbChecksumStore;
 import com.openexchange.drive.impl.DriveUtils;
 import com.openexchange.drive.impl.checksum.ChecksumProvider;
 import com.openexchange.drive.impl.checksum.ChecksumStore;
+import com.openexchange.drive.impl.checksum.ChecksumSupplier;
 import com.openexchange.drive.impl.checksum.DirectoryChecksum;
 import com.openexchange.drive.impl.checksum.FileChecksum;
+import com.openexchange.drive.impl.comparison.LazyServerDirectoryVersion;
 import com.openexchange.drive.impl.comparison.ServerDirectoryVersion;
 import com.openexchange.drive.impl.comparison.ServerFileVersion;
 import com.openexchange.drive.impl.management.DriveConfig;
@@ -63,6 +66,7 @@ public class SyncSession {
     private final DriveSession session;
     private final Tracer tracer;
     private final DriveConfig config;
+    private final long maxProcessingTime;
     private ChecksumStore checksumStore;
     private DriveStorage storage;
     private DirectLinkGenerator linkGenerator;
@@ -70,17 +74,27 @@ public class SyncSession {
     private DriveTemp temp;
     private PermissionResolver permissionResolver;
 
-
     /**
      * Initializes a new {@link SyncSession}.
      *
      * @param session The underlying drive session
      */
     public SyncSession(DriveSession session) {
+        this(session, -1L);
+    }
+
+    /**
+     * Initializes a new {@link SyncSession}.
+     *
+     * @param session The underlying drive session
+     * @param maxProcessingTime The maximum processing time (in milliseconds) to check against regularly, or <code>-1</code> if unrestricted
+     */
+    public SyncSession(DriveSession session, long maxProcessingTime) {
         super();
         this.session = session;
         this.config = new DriveConfig(session.getServerSession().getContextId(), session.getServerSession().getUserId());
         this.tracer = new Tracer(session.isDiagnostics());
+        this.maxProcessingTime = 0 < maxProcessingTime ? (System.nanoTime() + TimeUnit.MILLISECONDS.toNanos(maxProcessingTime)) : Long.MAX_VALUE;
         if (isTraceEnabled()) {
             trace("Initializing sync session for user " + session.getServerSession().getLoginName() + " (" +
                 session.getServerSession().getUserId() + ") in context " + session.getServerSession().getContextId() +
@@ -89,6 +103,18 @@ public class SyncSession {
         }
     }
 
+    /**
+     * Checks whether a configured maximum processing time is elapsed since this synch session was initialized. If this is the case, a
+     * corresponding exception is thrown to prematurely abort the current synchronization request.
+     *
+     * @throws OXException In case the maximum sync processing time is elapsed
+     */
+    private void checkMaxSyncProcessingTime() throws OXException {
+        if (System.nanoTime() > maxProcessingTime) {
+            throw DriveExceptionCodes.SERVER_BUSY.create(new Exception("Maximum processing time for current sync operation is exceeded."));
+        }
+    }
+
     /**
      * Gets the underlying server session
      *
@@ -112,7 +138,8 @@ public class SyncSession {
      *
      * @return The drive storage
      */
-    public DriveStorage getStorage() {
+    public DriveStorage getStorage() throws OXException {
+        checkMaxSyncProcessingTime();
         if (null == storage) {
             storage = new DriveStorage(this);
         }
@@ -155,6 +182,7 @@ public class SyncSession {
      * @return The checksum store
      */
     public ChecksumStore getChecksumStore() throws OXException {
+        checkMaxSyncProcessingTime();
         if (null == checksumStore) {
             checksumStore = new RdbChecksumStore(getServerSession().getContextId());
         }
@@ -324,8 +352,8 @@ public class SyncSession {
 
     /**
      * Gets a single directory version from the server. Only synchronized folders are taken into account, i.e. invalid and ignored
-     * directories are excluded. Missing directory checksums will be calculated on demand, and the folder is created implicitly in case
-     * it not already exists.
+     * directories are excluded. Missing directory checksums will be calculated on demand, however, the folder won't get created
+     * implicitly and an exception is thrown in case it not already exists.
      *
      * @param path The path to get the directory version for
      * @return The server directory versions
@@ -335,7 +363,7 @@ public class SyncSession {
 
             @Override
             public ServerDirectoryVersion call() throws OXException {
-                FileStorageFolder folder = getStorage().getFolder(path, true);
+                FileStorageFolder folder = getStorage().getFolder(path, false);
                 List<ServerDirectoryVersion> directoryVersions = getServerDirectoryVersions(Collections.singletonMap(path, folder));
                 return 0 < directoryVersions.size() ? directoryVersions.get(0) : null;
             }
@@ -353,13 +381,10 @@ public class SyncSession {
         List<String> folderIDs = new ArrayList<String>(folders.size());
         for (Map.Entry<String, FileStorageFolder> entry : folders.entrySet()) {
             String path = entry.getKey();
-            String folderID = entry.getValue().getId();
             if (DriveUtils.isInvalidPath(path) || FilenameValidationUtils.isInvalidFolderName(entry.getValue().getName())) {
-                trace("Skipping invalid server directory: " + entry.getKey());
+                trace("Skipping invalid server directory: " + path);
             } else if (DriveUtils.isIgnoredPath(this, path)) {
-                trace("Skipping ignored server directory: " + entry.getKey());
-            } else if (false == DriveUtils.isSynchronizable(folderID, getConfig())) {
-                trace("Skipping not synchronizable server directory: " + entry.getKey());
+                trace("Skipping ignored server directory: " + path);
             } else {
                 folderIDs.add(entry.getValue().getId());
             }
@@ -369,16 +394,30 @@ public class SyncSession {
             return Collections.emptyList();
         }
         StringBuilder stringBuilder = isTraceEnabled() ? new StringBuilder("Server directories:\n") : null;
-        List<DirectoryChecksum> checksums = ChecksumProvider.getChecksums(this, folderIDs);
         List<ServerDirectoryVersion> serverDirectories = new ArrayList<ServerDirectoryVersion>(folderIDs.size());
-        for (int i = 0; i < folderIDs.size(); i++) {
-            ServerDirectoryVersion directoryVersion = new ServerDirectoryVersion(
-                getStorage().getPath(folderIDs.get(i)), checksums.get(i));
-            serverDirectories.add(directoryVersion);
-            if (null != stringBuilder) {
-                stringBuilder.append(" [").append(directoryVersion.getDirectoryChecksum().getFolderID()).append("] ")
-                    .append(directoryVersion.getPath()).append(" | ").append(directoryVersion.getChecksum())
-                    .append(" (").append(directoryVersion.getDirectoryChecksum().getSequenceNumber()).append(")\n");
+        int lazyDirectoryChecksumChunkSize = 2 + getConfig().getMaxDirectoryActions();
+        if (lazyDirectoryChecksumChunkSize < folderIDs.size() && getConfig().isLazyDirectoryChecksumCalculation()) {
+            ChecksumSupplier checksumSupplier = new ChecksumSupplier(this, folderIDs, lazyDirectoryChecksumChunkSize);
+            for (String folderID : folderIDs) {
+                LazyServerDirectoryVersion directoryVersion = new LazyServerDirectoryVersion(getStorage().getPath(folderID), folderID, checksumSupplier);
+                serverDirectories.add(directoryVersion);
+                if (null != stringBuilder) {
+                    DirectoryChecksum checksum = directoryVersion.optDirectoryChecksum();
+                    stringBuilder.append(" [").append(folderID).append("] ")
+                        .append(directoryVersion.getPath()).append(" | ").append(null != checksum ? checksum.getChecksum() : "<pending>")
+                        .append(" (").append(null != checksum ? checksum.getSequenceNumber() : 0L).append(")\n");
+                }
+            }
+        } else {
+            List<DirectoryChecksum> checksums = ChecksumProvider.getChecksums(this, folderIDs);
+            for (int i = 0; i < folderIDs.size(); i++) {
+                ServerDirectoryVersion directoryVersion = new ServerDirectoryVersion(getStorage().getPath(folderIDs.get(i)), checksums.get(i));
+                serverDirectories.add(directoryVersion);
+                if (null != stringBuilder) {
+                    stringBuilder.append(" [").append(directoryVersion.getDirectoryChecksum().getFolderID()).append("] ")
+                        .append(directoryVersion.getPath()).append(" | ").append(directoryVersion.getChecksum())
+                        .append(" (").append(directoryVersion.getDirectoryChecksum().getSequenceNumber()).append(")\n");
+                }
             }
         }
         if (null != stringBuilder) {
