@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -347,7 +347,20 @@ public class UploadHelper {
             /*
              * append file data via random file access (not incrementing the version number)
              */
-            Entry<String, byte[]> entry = saveDocumentAndUpdateChecksum(uploadFile, uploadStream, uploadFile.getSequenceNumber(), modifiedFields, offset);
+            Entry<String, byte[]> entry;
+            try {
+                entry = saveDocumentAndUpdateChecksum(uploadFile, uploadStream, uploadFile.getSequenceNumber(), modifiedFields, offset);
+            } catch (OXException e) {
+                if ("FLS-0019".equals(e.getErrorCode())) {
+                    /*
+                     * wrong offset while appending file in storage, cleanup inconsistent state and yell
+                     */
+                    session.trace("Wrong offset detected by file storage: " + e.getMessage() + " Removing upload file to restart upload.");
+                    session.getStorage().deleteFile(uploadFile, true);
+                    throw DriveExceptionCodes.UNEXPECTED_ERROR.create(e, e.getMessage());
+                }
+                throw e;
+            }
             checksum = entry.getKey();
             if (entry.getValue() != null && -1 != totalLength && uploadFile.getFileSize() < totalLength) {
                 rememberChecksumState(uploadFile, entry.getValue());
