@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -25,6 +25,7 @@ import java.io.InputStream;
 import java.util.Date;
 import java.util.List;
 import java.util.concurrent.atomic.AtomicInteger;
+import com.google.common.util.concurrent.AtomicLongMap;
 import com.openexchange.ajax.fileholder.IFileHolder;
 import com.openexchange.drive.DirectoryMetadata;
 import com.openexchange.drive.DirectoryVersion;
@@ -40,7 +41,7 @@ import com.openexchange.drive.FileVersion;
 import com.openexchange.drive.SyncResult;
 import com.openexchange.drive.impl.management.DriveConfig;
 import com.openexchange.exception.OXException;
-import com.openexchange.tools.session.ServerSession;
+import com.openexchange.session.UserAndContext;
 
 /**
  * {@link ThrottlingDriveService}
@@ -51,6 +52,8 @@ public class ThrottlingDriveService implements DriveService {
 
     private final DriveService delegate;
     private final AtomicInteger currentSyncOperations;
+    private final AtomicLongMap<UserAndContext> concurrentSyncFiles;
+    private final AtomicLongMap<UserAndContext> concurrentSyncFolders;
 
     /**
      * Initializes a new {@link ThrottlingDriveService}.
@@ -62,35 +65,115 @@ public class ThrottlingDriveService implements DriveService {
         super();
         this.delegate = delegate;
         currentSyncOperations = new AtomicInteger();
+        concurrentSyncFiles = AtomicLongMap.create();
+        concurrentSyncFolders = AtomicLongMap.create();
+    }
+
+    @SuppressWarnings("synthetic-access")
+    private class SyncMonitor {
+
+        private final DriveSession session;
+        private final UserAndContext userAndContext;
+
+        boolean syncOperationsIncremented;
+        boolean syncFoldersOperationsIncremented;
+        boolean syncFilesOperationsIncremented;
+
+        SyncMonitor(DriveSession session) {
+            this.session = session;
+            this.userAndContext = UserAndContext.newInstance(session.getServerSession());
+        }
+
+        void enterSyncOperation() throws OXException {
+            int maxConcurrentSyncOperations = new DriveConfig(session.getServerSession().getContextId(), session.getServerSession().getUserId()).getMaxConcurrentSyncOperations();
+            if (0 < maxConcurrentSyncOperations) {
+                int currentSyncOps = currentSyncOperations.incrementAndGet();
+                syncOperationsIncremented = true;
+                if (maxConcurrentSyncOperations < currentSyncOps) {
+                    throw DriveExceptionCodes.SERVER_BUSY.create();
+                }
+            }
+        }
+
+        void leaveSyncOperation() {
+            if (syncOperationsIncremented) {
+                currentSyncOperations.decrementAndGet();
+            }
+        }
+
+        void enterSyncFoldersOperation() throws OXException {
+            int maxConcurrentSyncFolders = new DriveConfig(session.getServerSession().getContextId(), session.getServerSession().getUserId()).getMaxConcurrentSyncFolders();
+            if (0 < maxConcurrentSyncFolders) {
+                long currentSyncFoldersOps = concurrentSyncFolders.incrementAndGet(userAndContext);
+                syncFoldersOperationsIncremented = true;
+                if (maxConcurrentSyncFolders < currentSyncFoldersOps) {
+                    throw DriveExceptionCodes.SERVER_BUSY.create();
+                }
+            }
+        }
+
+        void leaveSyncFoldersOperation() {
+            if (syncFoldersOperationsIncremented) {
+                concurrentSyncFolders.decrementAndGet(userAndContext);
+                concurrentSyncFolders.removeIfZero(userAndContext);
+            }
+        }
+
+        void enterSyncFilesOperation() throws OXException {
+            int maxConcurrentSyncFiles = new DriveConfig(session.getServerSession().getContextId(), session.getServerSession().getUserId()).getMaxConcurrentSyncFiles();
+            if (0 < maxConcurrentSyncFiles) {
+                long currentSyncFilesOps = concurrentSyncFiles.incrementAndGet(userAndContext);
+                syncFilesOperationsIncremented = true;
+                if (maxConcurrentSyncFiles < currentSyncFilesOps) {
+                    throw DriveExceptionCodes.SERVER_BUSY.create();
+                }
+            }
+        }
+
+        void leaveSyncFilesOperation() {
+            if (syncFilesOperationsIncremented) {
+                concurrentSyncFiles.decrementAndGet(userAndContext);
+                concurrentSyncFiles.removeIfZero(userAndContext);
+            }
+        }
     }
 
     @Override
     public SyncResult<DirectoryVersion> syncFolder(DriveSession session, DirectoryVersion originalVersion, DirectoryVersion clientVersion) throws OXException {
+        SyncMonitor monitor = new SyncMonitor(session);
         try {
-            enterSyncOperation(session);
+            monitor.enterSyncOperation();
+            monitor.enterSyncFoldersOperation();
             return delegate.syncFolder(session, originalVersion, clientVersion);
         } finally {
-            leaveSyncOperation();
+            monitor.leaveSyncFoldersOperation();
+            monitor.leaveSyncOperation();
         }
     }
 
     @Override
     public SyncResult<DirectoryVersion> syncFolders(DriveSession session, List<DirectoryVersion> originalVersions, List<DirectoryVersion> clientVersions) throws OXException {
+        SyncMonitor monitor = new SyncMonitor(session);
         try {
-            enterSyncOperation(session);
+            monitor.enterSyncOperation();
+            monitor.enterSyncFoldersOperation();
             return delegate.syncFolders(session, originalVersions, clientVersions);
         } finally {
-            leaveSyncOperation();
+            monitor.leaveSyncFoldersOperation();
+            monitor.leaveSyncOperation();
         }
     }
 
     @Override
     public SyncResult<FileVersion> syncFiles(DriveSession session, String path, List<FileVersion> originalVersions, List<FileVersion> clientVersions) throws OXException {
+        SyncMonitor monitor = new SyncMonitor(session);
         try {
-            enterSyncOperation(session);
+            monitor.enterSyncOperation();
+            monitor.enterSyncFilesOperation();
             return delegate.syncFiles(session, path, originalVersions, clientVersions);
         } finally {
-            leaveSyncOperation();
+            monitor.leaveSyncFilesOperation();
+            monitor.leaveSyncOperation();
         }
     }
 
@@ -100,19 +183,22 @@ public class ThrottlingDriveService implements DriveService {
     }
 
     @Override
+    //@formatter:off
     public SyncResult<FileVersion> upload(DriveSession session, String path, InputStream uploadStream, FileVersion originalVersion,
         FileVersion newVersion, String contentType, long offset, long totalLength, Date created, Date modified) throws OXException {
         return delegate.upload(
             session, path, uploadStream, originalVersion, newVersion, contentType, offset, totalLength, created, modified);
     }
+    //@formatter:on
 
     @Override
     public DriveQuota getQuota(DriveSession session) throws OXException {
+        SyncMonitor monitor = new SyncMonitor(session);
         try {
-            enterSyncOperation(session);
+            monitor.enterSyncOperation();
             return delegate.getQuota(session);
         } finally {
-            leaveSyncOperation();
+            monitor.leaveSyncOperation();
         }
     }
 
@@ -123,21 +209,23 @@ public class ThrottlingDriveService implements DriveService {
 
     @Override
     public List<DriveFileMetadata> getFileMetadata(DriveSession session, String path, List<FileVersion> fileVersions, List<DriveFileField> fields) throws OXException {
+        SyncMonitor monitor = new SyncMonitor(session);
         try {
-            enterSyncOperation(session);
+            monitor.enterSyncOperation();
             return delegate.getFileMetadata(session, path, fileVersions, fields);
         } finally {
-            leaveSyncOperation();
+            monitor.leaveSyncOperation();
         }
     }
 
     @Override
     public DirectoryMetadata getDirectoryMetadata(DriveSession session, String path) throws OXException {
+        SyncMonitor monitor = new SyncMonitor(session);
         try {
-            enterSyncOperation(session);
+            monitor.enterSyncOperation();
             return delegate.getDirectoryMetadata(session, path);
         } finally {
-            leaveSyncOperation();
+            monitor.leaveSyncOperation();
         }
     }
 
@@ -151,16 +239,4 @@ public class ThrottlingDriveService implements DriveService {
         return delegate.getUtility();
     }
 
-    private void enterSyncOperation(DriveSession session) throws OXException {
-        ServerSession serverSession = session.getServerSession();
-        int maxConcurrentSyncOperations = new DriveConfig(serverSession.getContextId(), serverSession.getUserId()).getMaxConcurrentSyncOperations();
-        if (0 < maxConcurrentSyncOperations && maxConcurrentSyncOperations < currentSyncOperations.incrementAndGet()) {
-            throw DriveExceptionCodes.SERVER_BUSY.create();
-        }
-    }
-
-    private void leaveSyncOperation() {
-        currentSyncOperations.decrementAndGet();
-    }
-
 }
