@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -21,6 +21,7 @@
 
 package com.openexchange.drive.impl.management;
 
+import static com.openexchange.java.Autoboxing.I;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashSet;
@@ -435,6 +436,17 @@ public class DriveConfig {
         return getConfigService().getIntProperty(userId, contextId, DriveProperty.MAX_CONCURRENT_SYNCFILES);
     }
 
+    /**
+     * Gets the maxConcurrentSyncFolders
+     *
+     * @param contextId The context identifier
+     * @param userId The user identifier
+     * @return The maxConcurrentSyncFolders
+     */
+    public int getMaxConcurrentSyncFolders() {
+        return getConfigService().getIntProperty(userId, contextId, DriveProperty.MAX_CONCURRENT_SYNCFOLDERS);
+    }
+
     /**
      * Gets the maxFilesPerDirectory
      *
@@ -541,6 +553,34 @@ public class DriveConfig {
         return parseBytes(getConfigService().getProperty(userId, contextId, DriveProperty.OPTIMISTIC_SAVE_THRESHOLD_DESKTOP));
     }
 
+    /**
+     * Gets a value indicating whether directory checksums should be calculated in a lazy way or not. If enabled, server directory
+     * checksums will be retrieved in chunks according to the configured "maxDirectoryActions", which may reduce the processing time for
+     * the initial sync of large directory subtrees.
+     *
+     * @return <code>true</code> if lazy directory calculation is enabled, <code>false</code>, otherwise
+     */
+    public boolean isLazyDirectoryChecksumCalculation() {
+        return getConfigService().getBooleanProperty(userId, contextId, DriveProperty.LAZY_DIRECTORY_CHECKSUM_CALCULATION);
+    }
+
+    /**
+     * Gets the processing time (in seconds) after a running syncFiles- or syncFolders-operation is cancelled. This can be helpful
+     * during initial synchronizations where no previously calculated checksums are available, and a long running request would otherwise be
+     * interrupted by a proxy timeout. The value can be defined using units of measurement: "m" (=minutes), "s" (=seconds) and "m" (=minutes).
+     *
+     * @return The maximum sync processing time (in milliseconds)
+     */
+    public long getMaxSyncProcessingTime() {
+        String value = getConfigService().getProperty(userId, contextId, DriveProperty.MAX_SYNC_PROCESSING_TIME);
+        try {
+            return TimeSpanParser.parseTimespanToPrimitive(value);
+        } catch (IllegalArgumentException e) {
+            LoggerHolder.LOG.warn("{} configuration error for user {} in context {}", DriveProperty.MAX_SYNC_PROCESSING_TIME.getFQPropertyName(), I(userId), I(contextId), e);
+            return TimeSpanParser.parseTimespanToPrimitive(DriveProperty.MAX_SYNC_PROCESSING_TIME.getDefaultValue(String.class));
+        }
+    }
+
     /**
      * Parse Drive client version
      *
