@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -104,7 +104,7 @@ public class JsonDirectoryMetadata extends AbstractJsonMetadata {
             JSONObject jsonObject = new JSONObject();
             jsonObject.put("id", folder.getId());
             String localizedName = folder.getLocalizedName(session.getDriveSession().getLocale());
-            if (Strings.isNotEmpty(localizedName) && false == localizedName.equals(folder.getName())) {
+            if (Strings.isNotEmpty(localizedName)) {
                 jsonObject.put("localized_name", localizedName);
             }
             if (folder.isDefaultFolder()) {
@@ -142,6 +142,7 @@ public class JsonDirectoryMetadata extends AbstractJsonMetadata {
             }
             Set<String> capabilities = folder.getCapabilities();
             if (null != capabilities && capabilities.contains(FileStorageFolder.CAPABILITY_PERMISSIONS)) {
+                session.getPermissionResolver().cacheFileStorageFolderPermissionEntities(Collections.singletonList(folder));
                 jsonObject.put("own_rights", createPermissionBits(folder.getOwnPermission()));
                 jsonObject.putOpt("permissions", getJSONPermissions(folder.getPermissions(), false));
                 jsonObject.putOpt("extended_permissions", getJSONPermissions(folder.getPermissions(), true));
