@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -24,6 +24,7 @@ package com.openexchange.drive.impl.metadata;
 import static com.openexchange.java.Autoboxing.I;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.Date;
 import java.util.HashSet;
 import java.util.List;
@@ -101,6 +102,7 @@ public class JsonFileMetadata extends AbstractJsonMetadata {
                 }
                 break;
             case OBJECT_PERMISSIONS:
+                session.getPermissionResolver().cacheFilePermissionEntities(Collections.singletonList(file));
                 jsonObject.putOpt("object_permissions", getJSONObjectPermissions(file.getObjectPermissions(), false));
                 jsonObject.putOpt("extended_object_permissions", getJSONObjectPermissions(file.getObjectPermissions(), true));
                 if (isShared(file)) {
