@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -35,10 +35,12 @@ import java.util.Date;
 import java.util.HashMap;
 import java.util.LinkedList;
 import java.util.List;
+import java.util.Locale;
 import java.util.Map;
 import java.util.Objects;
 import java.util.Optional;
 import java.util.Set;
+import java.util.TreeMap;
 import com.openexchange.drive.DriveExceptionCodes;
 import com.openexchange.drive.FolderStats;
 import com.openexchange.drive.RestoreContent;
@@ -846,10 +848,11 @@ public class DriveStorage {
      * Gets the directory path to internal 'real' root folder with id '9'
      *
      * @param folderId The folder identifier to get the path for
+     * @param locale The locale to use for translating the folder names, or <code>null</code> to use the untranslated names
      * @return The path
      */
-    public String getInternalPath(String folderId) throws OXException {
-        return resolveToRoot(folderId, "9", null);
+    public String getInternalPath(String folderId, Locale locale) throws OXException {
+        return resolveToRoot(folderId, "9", null, locale);
     }
 
     /**
@@ -971,13 +974,15 @@ public class DriveStorage {
     /**
      * Gets all folders in the storage recursively. The "temp" folder, as well as the trash folder including all subfolders are ignored
      * implicitly.
+     * <p/>
+     * Folders will be returned in a map, sorted by their associated <i>path</i> ascending, case-insensitive.
      *
      * @param limit The maximum number of folders to add, or <code>-1</code> for no limitations
      * @param maxDepth The maximum subtree depth folders to add, or <code>-1</code> for no limitations
      * @return The folders, each one mapped to its corresponding relative path
      */
     public Map<String, FileStorageFolder> getFolders(int limit, int maxDepth) throws OXException {
-        Map<String, FileStorageFolder> folders = new HashMap<String, FileStorageFolder>();
+        Map<String, FileStorageFolder> folders = new TreeMap<String, FileStorageFolder>(String.CASE_INSENSITIVE_ORDER);
         FileStorageFolder rootFolder = getRootFolder();
         folders.put(ROOT_PATH, rootFolder);
         if (0 != maxDepth) {
@@ -1084,8 +1089,12 @@ public class DriveStorage {
     private String resolveToRoot(String folderID) throws OXException {
         return resolveToRoot(folderID, rootFolderID.toUniqueID(), knownFolders);
     }
-
+    
     private String resolveToRoot(String folderID, String rootFolderID, FolderCache folderCache) throws OXException {
+        return resolveToRoot(folderID, rootFolderID, folderCache, null);
+    }
+
+    private String resolveToRoot(String folderID, String rootFolderID, FolderCache folderCache, Locale locale) throws OXException {
         LinkedList<FileStorageFolder> folders = new LinkedList<FileStorageFolder>();
         String currentFolderID = folderID;
         do {
@@ -1097,9 +1106,13 @@ public class DriveStorage {
             StringBuilder pathBuilder = new StringBuilder();
             for (int i = 0; i < folders.size(); i++) {
                 FileStorageFolder folder = folders.get(i);
-                pathBuilder.append(PATH_SEPARATOR).append(PathNormalizer.normalize(folder.getName()));
-                if (null != folderCache) {
-                    folderCache.remember(pathBuilder.toString(), folder);
+                if (null == locale) {
+                    pathBuilder.append(PATH_SEPARATOR).append(PathNormalizer.normalize(folder.getName()));
+                    if (null != folderCache) {
+                        folderCache.remember(pathBuilder.toString(), folder);
+                    }
+                } else {
+                    pathBuilder.append(PATH_SEPARATOR).append(PathNormalizer.normalize(folder.getName(locale)));
                 }
             }
             return pathBuilder.toString();
