@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -220,9 +220,9 @@ public class FileActionExecutor extends BatchActionExecutor<FileVersion> {
             metadata.setVersionComment(session.getStorage().getVersionComment());
             InputStream data = new UnsynchronizedByteArrayInputStream(new byte[0]);
             File createdFile = session.getStorage().createFile(path, action.getNewVersion().getName(), metadata, data);
-            FileChecksum insertedFileChecksum = session.getChecksumStore().insertFileChecksum(new FileChecksum(
-                DriveUtils.getFileID(createdFile), createdFile.getVersion(), createdFile.getSequenceNumber(), DriveConstants.EMPTY_MD5));
-            action.setResultingVersion(new ServerFileVersion(createdFile, insertedFileChecksum));
+            FileChecksum createdFileChecksum = new FileChecksum(
+                DriveUtils.getFileID(createdFile), createdFile.getVersion(), createdFile.getSequenceNumber(), DriveConstants.EMPTY_MD5);
+            action.setResultingVersion(new ServerFileVersion(createdFile, createdFileChecksum));
             return;
         }
         /*
