@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -40,6 +40,7 @@ public class DefaultSyncResult<T extends DriveVersion> implements SyncResult<T>
     private final String diagnosticsLog;
     private final DriveQuota quota;
     private final String pathToRoot;
+    private final String localizedPathToRoot;
 
     /**
      * 
@@ -49,7 +50,7 @@ public class DefaultSyncResult<T extends DriveVersion> implements SyncResult<T>
      * @param diagnosticsLog The diagnostics log
      */
     public DefaultSyncResult(List<AbstractAction<T>> actionsForClient, String diagnosticsLog) {
-        this(actionsForClient, diagnosticsLog, null, null);
+        this(actionsForClient, diagnosticsLog, null, null, null);
     }
 
     /**
@@ -59,8 +60,9 @@ public class DefaultSyncResult<T extends DriveVersion> implements SyncResult<T>
      * @param diagnosticsLog The diagnostics log
      * @param quota The quota information
      * @param pathToRoot The sync'ed root folder's path to the internal root folder
+     * @param localizedPathToRoot The localized sync'ed root folder's path to the internal root folder
      */
-    public DefaultSyncResult(List<AbstractAction<T>> actionsForClient, String diagnosticsLog, DriveQuota quota, String pathToRoot) {
+    public DefaultSyncResult(List<AbstractAction<T>> actionsForClient, String diagnosticsLog, DriveQuota quota, String pathToRoot, String localizedPathToRoot) {
         super();
         this.actionsForClient = new ArrayList<DriveAction<T>>(actionsForClient.size());
         for (DriveAction<? extends T> driveAction : actionsForClient) {
@@ -69,6 +71,7 @@ public class DefaultSyncResult<T extends DriveVersion> implements SyncResult<T>
         this.diagnosticsLog = diagnosticsLog;
         this.quota = quota;
         this.pathToRoot = pathToRoot;
+        this.localizedPathToRoot = localizedPathToRoot;
     }
 
     @Override
@@ -91,6 +94,11 @@ public class DefaultSyncResult<T extends DriveVersion> implements SyncResult<T>
         return pathToRoot;
     }
 
+    @Override
+    public String getLocalizedPathToRoot() {
+        return localizedPathToRoot;
+    }
+
     @Override
     public String toString() {
         StringBuilder StringBuilder = new StringBuilder();
