@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -42,6 +42,7 @@ import com.openexchange.drive.impl.internal.SyncSession;
 import com.openexchange.drive.impl.sync.IntermediateSyncResult;
 import com.openexchange.exception.OXException;
 import com.openexchange.file.storage.composition.FolderID;
+import com.openexchange.java.Strings;
 
 
 /**
@@ -281,8 +282,8 @@ public class DirectoryRenameOptimizer extends DirectoryActionOptimizer {
         } else if (path1.equals(path2)) {
             return Integer.MAX_VALUE;
         }
-        String[] splitted1 = path1.split("/");
-        String[] splitted2 = path2.split("/");
+        String[] splitted1 = Strings.splitBy(path1, '/', true);
+        String[] splitted2 = Strings.splitBy(path2, '/', true);
         int score = 0;
         int minLength = Math.min(splitted1.length, splitted2.length);
         for (int i = 0; i < minLength; i++) {
