@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -24,9 +24,15 @@ package com.openexchange.drive.json.action;
 import static com.openexchange.osgi.Tools.requireService;
 import java.net.InetAddress;
 import java.net.UnknownHostException;
+import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collections;
+import java.util.List;
 import java.util.Locale;
 import javax.servlet.http.HttpServletRequest;
+import org.json.JSONArray;
+import org.json.JSONException;
+import org.json.JSONObject;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
@@ -35,16 +41,23 @@ import com.openexchange.capabilities.CapabilityService;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.dispatcher.DispatcherPrefixService;
 import com.openexchange.drive.DriveClientVersion;
+import com.openexchange.drive.DriveExceptionCodes;
 import com.openexchange.drive.DriveService;
 import com.openexchange.drive.DriveSession;
 import com.openexchange.drive.events.subscribe.DriveSubscriptionStore;
+import com.openexchange.drive.events.subscribe.Subscription;
 import com.openexchange.drive.events.subscribe.SubscriptionMode;
 import com.openexchange.drive.json.DriveShareJSONParser;
 import com.openexchange.drive.json.internal.DefaultDriveSession;
 import com.openexchange.drive.json.internal.Services;
 import com.openexchange.drive.json.json.DriveFieldMapper;
 import com.openexchange.exception.OXException;
+import com.openexchange.folderstorage.FolderService;
+import com.openexchange.folderstorage.FolderStorage;
+import com.openexchange.folderstorage.database.contentType.InfostoreContentType;
+import com.openexchange.folderstorage.type.PrivateType;
 import com.openexchange.framework.request.RequestContextHolder;
+import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.notify.hostname.HostData;
 import com.openexchange.groupware.notify.hostname.HostnameService;
 import com.openexchange.i18n.LocaleTools;
@@ -389,4 +402,91 @@ public abstract class AbstractDriveAction implements AJAXActionService {
         requestData.putParameter("transformationNeeded", String.valueOf(false));
     }
 
+    /**
+     * Extracts the root folder identifier(s) to use for the (un)subscription of push notifications, either the explicitly passed folder
+     * ids, or based on the static push domain names.
+     * 
+     * @param requestData The request data
+     * @return The root folder identifiers, or <code>null</code> if none were supplied
+     */
+    protected List<String> extractPushRootFolderIDs(AJAXRequestData requestData) throws OXException {
+        /*
+         * probe for "root" array in body
+         */
+        Object data = requestData.getData();
+        if (null != data) {
+            if (false == JSONObject.class.isInstance(data)) {
+                throw AjaxExceptionCodes.MISSING_REQUEST_BODY.create();
+            }
+            JSONObject dataObject = (JSONObject) data;
+            JSONArray rootArray = dataObject.optJSONArray("root");
+            if (null != rootArray && 0 < rootArray.length()) {
+                List<String> rootFolderIDs = new ArrayList<String>(rootArray.length());
+                try {
+                    for (int i = 0; i < rootArray.length(); i++) {
+                        rootFolderIDs.add(rootArray.getString(i));
+                    }
+                } catch (JSONException e) {
+                    throw AjaxExceptionCodes.JSON_ERROR.create(e, e.getMessage());
+                }
+                return rootFolderIDs;
+            }
+        }
+        /*
+         * probe for "root" parameter
+         */
+        String root = requestData.getParameter("root");
+        if (Strings.isNotEmpty(root)) {
+            return Collections.singletonList(root);
+        }
+        /*
+         * probe for "domain" array in body
+         */
+        if (null != data) {
+            JSONObject dataObject = (JSONObject) data;
+            JSONArray domainArray = dataObject.optJSONArray("domain");
+            if (null != domainArray && 0 < domainArray.length()) {
+                List<String> rootFolderIDs = new ArrayList<String>(domainArray.length());
+                try {
+                    for (int i = 0; i < domainArray.length(); i++) {
+                        rootFolderIDs.add(getRootFromDomain(requestData.getSession(), domainArray.getString(i)));
+                    }
+                } catch (JSONException e) {
+                    throw AjaxExceptionCodes.JSON_ERROR.create(e, e.getMessage());
+                }
+                return rootFolderIDs;
+            }
+        }
+        /*
+         * probe for "domain" parameter
+         */
+        String domain = requestData.getParameter("domain");
+        if (Strings.isNotEmpty(domain)) {
+            return Collections.singletonList(getRootFromDomain(requestData.getSession(), domain));
+        }
+        return null;
+    }
+
+    /**
+     * Derives the root folder identifier from the supplied push domain value.
+     * 
+     * @param session The user's session
+     * @param pushDomain The push domain
+     * @return The root folder id
+     */
+    protected String getRootFromDomain(ServerSession session, String pushDomain) throws OXException {
+        if (Subscription.DOMAIN_MY_FILES.equals(pushDomain)) {
+            FolderService folderService = Services.getService(FolderService.class, true);
+            return folderService.getDefaultFolder(session.getUser(), FolderStorage.REAL_TREE_ID, 
+                InfostoreContentType.getInstance(), PrivateType.getInstance(), session, null).getID();
+        }
+        if (Subscription.DOMAIN_SHARED_FILES.equals(pushDomain)) {
+            return String.valueOf(FolderObject.SYSTEM_USER_INFOSTORE_FOLDER_ID);
+        }
+        if (Subscription.DOMAIN_PUBLIC_FILES.equals(pushDomain)) {
+            return String.valueOf(FolderObject.SYSTEM_PUBLIC_INFOSTORE_FOLDER_ID);
+        }
+        throw DriveExceptionCodes.UNEXPECTED_ERROR.create("Unknown push domain " + pushDomain);
+    }
+
 }
