@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -29,7 +29,7 @@ import com.openexchange.ajax.requesthandler.annotation.restricted.RestrictedActi
  * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
  * @since 7.10.4
  */
-@RestrictedAction(module = AbstractDriveWriteAction.MODULE, type = RestrictedAction.Type.WRITE)
+@RestrictedAction(module = AbstractDriveAction.MODULE, type = RestrictedAction.Type.WRITE)
 public abstract class AbstractDriveWriteAction extends AbstractDriveAction {
 
     /**
