@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -21,16 +21,14 @@
 
 package com.openexchange.drive.json.action;
 
-import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
-import org.json.JSONArray;
-import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.drive.events.subscribe.DriveSubscriptionStore;
 import com.openexchange.drive.events.subscribe.SubscriptionMode;
+import com.openexchange.drive.events.subscribe.SubscriptionTransport;
 import com.openexchange.drive.json.internal.DefaultDriveSession;
 import com.openexchange.drive.json.internal.Services;
 import com.openexchange.exception.OXException;
@@ -62,33 +60,20 @@ public class SubscribeAction extends AbstractDriveWriteAction {
         if (Strings.isEmpty(serviceID)) {
             throw AjaxExceptionCodes.MISSING_PARAMETER.create("service");
         }
-        /*
-         * get optional root folder identifiers, falling back to the session's default root folder id
-         */
-        List<String> rootFolderIDs = null;
-        Object data = requestData.getData();
-        if (null != data) {
-            if (false == JSONObject.class.isInstance(data)) {
-                throw AjaxExceptionCodes.MISSING_REQUEST_BODY.create();
-            }
-            JSONObject dataObject = (JSONObject) data;
-            JSONArray rootArray = dataObject.optJSONArray("root");
-            if (null != rootArray && 0 < rootArray.length()) {
-                rootFolderIDs = new ArrayList<String>(rootArray.length());
-                try {
-                    for (int i = 0; i < rootArray.length(); i++) {
-                        rootFolderIDs.add(rootArray.getString(i));
-                    }
-                } catch (JSONException e) {
-                    throw AjaxExceptionCodes.JSON_ERROR.create(e, e.getMessage());
-                }
-            }
+        List<OXException> warnings = null;
+        if (serviceID.toUpperCase().equals(SubscriptionTransport.GCM.name())) {
+            serviceID = SubscriptionTransport.FCM.name().toLowerCase();
+            // Add a warning if the subscription transport is GCM and set it to FCM
+            // After GCM is completely dropped, we should simply throw an exception and return with 400
+
+            warnings = Collections.singletonList(AjaxExceptionCodes.INVALID_PARAMETER_VALUE.create("service", serviceID));
         }
-        if (null == rootFolderIDs) {
-            if (Strings.isEmpty(session.getRootFolderID())) {
-                throw AjaxExceptionCodes.MISSING_PARAMETER.create("root");
-            }
-            rootFolderIDs = Collections.singletonList(session.getRootFolderID());
+        /*
+         * extract root folder identifier(s), either directly, or based on representative domains
+         */
+        List<String> rootFolderIDs = extractPushRootFolderIDs(requestData);
+        if (null == rootFolderIDs || rootFolderIDs.isEmpty()) {
+            throw AjaxExceptionCodes.MISSING_PARAMETER.create("root / domain");
         }
         /*
          * get subscription mode if set
@@ -102,7 +87,7 @@ public class SubscribeAction extends AbstractDriveWriteAction {
         /*
          * return empty json object to indicate success
          */
-        return new AJAXRequestResult(new JSONObject(0), "json");
+        return new AJAXRequestResult(new JSONObject(0), "json").addWarnings(warnings);
     }
 
 }
