@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -21,6 +21,8 @@
 
 package com.openexchange.drive;
 
+import com.openexchange.exception.OXException;
+
 /**
  * {@link DirectoryPattern}
  *
@@ -34,6 +36,6 @@ public interface DirectoryPattern {
      * @param path The path of the directory to check
      * @return <code>true</code> if it matches, <code>false</code>, otherwise
      */
-    boolean matches(String path);
+    boolean matches(String path) throws OXException;
 
 }
