@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -22,6 +22,7 @@
 package com.openexchange.drive;
 
 import java.util.Arrays;
+import com.openexchange.java.Strings;
 
 /**
  * {@link DriveClientVersion}
@@ -51,7 +52,7 @@ public class DriveClientVersion implements Comparable<DriveClientVersion> {
             throw new IllegalArgumentException(version);
         }
         this.version = version;
-        String[] parts = version.split("\\.");
+        String[] parts = Strings.splitByDots(version);
         versionParts = new int[parts.length];
         try {
             for (int i = 0; i < parts.length; i++) {
