@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -133,6 +133,13 @@ public enum DriveProperty implements Property {
      */
     MAX_CONCURRENT_SYNCFILES("maxConcurrentSyncFiles", I(10)),
 
+    /**
+     * Gets the configured limit for concurrent syncFolders-Operation that is indicated
+     * to clients.
+     * Default: 3
+     */
+    MAX_CONCURRENT_SYNCFOLDERS("maxConcurrentSyncFolders", I(3)),
+
     /**
      * Defines the maximum number of synchronizable directories per root folder. A
      * value of "-1" disables the limitation.
@@ -335,7 +342,7 @@ public enum DriveProperty implements Property {
      * REGEX-pattern to filter directory names to exclude from sync
      * Default: TODO: find a way to put default value here...
      */
-    EXCLUDED_DIRECTORIES_PATTERN("excludedDirectoriesPattern", "^/\\.drive$|^.*/\\.msngr_hstr_data$|^.*/\\.drive-meta(?:$|/.*)"),
+    EXCLUDED_DIRECTORIES_PATTERN("excludedDirectoriesPattern", "^/\\.drive(?:$|/.*)|^.*/\\.msngr_hstr_data$|^.*/\\.drive-meta(?:$|/.*)"),
 
     /**
      * Gets the maximum number of actions to be evaluated per synchronization request. Any further open actions will need to be handled in
@@ -432,7 +439,27 @@ public enum DriveProperty implements Property {
      * temporary upload file first.
      * Default: 64kB
      */
-    OPTIMISTIC_SAVE_THRESHOLD_MOBILE("optimisticSaveThresholdMobile", "64kB")
+    OPTIMISTIC_SAVE_THRESHOLD_MOBILE("optimisticSaveThresholdMobile", "64kB"),
+
+    /**
+     * Configures whether directory checksums should be calculated in a lazy way or not. If enabled, server directory checksums will be
+     * retrieved in chunks according to the configured "maxDirectoryActions", which may reduce the processing time for the initial sync of
+     * large directory subtrees.
+     * <p/>
+     * Default: true
+     */
+    LAZY_DIRECTORY_CHECKSUM_CALCULATION("lazyDirectoryChecksumCalculation", Boolean.TRUE),
+
+    /**
+     * Configures the processing time (in seconds) after a running syncFiles- or syncFolders-operation is cancelled. This can be helpful
+     * during initial synchronizations where no previously calculated checksums are available, and a long running request would otherwise be
+     * interrupted by a proxy timeout. The value can be defined using units of measurement: "m" (=minutes), "s" (=seconds) and "ms"
+     * (=milliseconds).
+     * <p/>
+     * Default: 90s
+     */
+    MAX_SYNC_PROCESSING_TIME("maxSyncProcessingTime", "90s"),
+
     ;
 
     private static final String PREFIX = "com.openexchange.drive.";
