@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -42,6 +42,7 @@ public class DriveSettings {
     private int minSearchChars;
     private boolean hasTrashFolder;
     private String pathToRoot;
+    private String localizedPathToRoot;
     private int maxConcurrentSyncFiles;
 
     /**
@@ -249,6 +250,24 @@ public class DriveSettings {
         this.pathToRoot = pathToRoot;
     }
 
+    /**
+     * Gets the localized path from driveRootFolder to internal 'real' root folder
+     *
+     * @return The localized path
+     */
+    public String getLocalizedPathToRoot() {
+        return localizedPathToRoot;
+    }
+
+    /**
+     * Sets the localized path from driveRootFolder to internal 'real' root folder
+     *
+     * @param localizedPathToRoot The localized path to set
+     */
+    public void setLocalizedPathToRoot(String localizedPathToRoot) {
+        this.localizedPathToRoot = localizedPathToRoot;
+    }
+
     /**
      * Gets the maxConcurrentSyncFiles
      *
@@ -266,5 +285,5 @@ public class DriveSettings {
     public void setMaxConcurrentSyncFiles(int maxConcurrentSyncFiles) {
         this.maxConcurrentSyncFiles = maxConcurrentSyncFiles;
     }
-
+    
 }
