@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -21,6 +21,8 @@
 
 package com.openexchange.drive;
 
+import com.openexchange.exception.OXException;
+
 /**
  * {@link FilePattern}
  *
@@ -35,6 +37,6 @@ public interface FilePattern {
      * @param name The name of the file to check
      * @return <code>true</code> if it matches, <code>false</code>, otherwise
      */
-    boolean matches(String path, String name);
+    boolean matches(String path, String name) throws OXException;
 
 }
