@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -59,4 +59,11 @@ public interface SyncResult<T extends DriveVersion> {
      */
     String getPathToRoot();
 
+    /**
+     * Gets the localized path from driveRootFolder to internal 'real' root folder
+     *
+     * @return The localized path
+     */
+    String getLocalizedPathToRoot();
+
 }
